# accessibletranslator-python
Official SDK API for AccessibleTranslator - automated cognitive accessibility

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.1.0
- Package version: 1.1.0
- Generator version: 7.14.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.9+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import accessibletranslator
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import accessibletranslator
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import accessibletranslator
from accessibletranslator.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://api.accessibletranslator.com
# See configuration.py for a list of all supported configuration parameters.
configuration = accessibletranslator.Configuration(
    host = "https://api.accessibletranslator.com"
)



# Enter a context with an instance of the API client
async with accessibletranslator.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = accessibletranslator.SystemApi(api_client)

    try:
        # Public Health Check
        api_response = await api_instance.check()
        print("The response of SystemApi->check:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling SystemApi->check: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://api.accessibletranslator.com*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*SystemApi* | [**check**](docs/SystemApi.md#check) | **GET** /health | Public Health Check
*TranslationApi* | [**target_languages**](docs/TranslationApi.md#target_languages) | **GET** /api/target-languages | Get Available Target Languages
*TranslationApi* | [**transformations**](docs/TranslationApi.md#transformations) | **GET** /api/transformations | Get Available Transformations
*TranslationApi* | [**translate**](docs/TranslationApi.md#translate) | **POST** /api/translate | Translate Text
*UserManagementApi* | [**word_balance**](docs/UserManagementApi.md#word_balance) | **GET** /users/word-balance | Get Word Balance


## Documentation For Models

 - [BasicHealthCheck](docs/BasicHealthCheck.md)
 - [FunctionInfo](docs/FunctionInfo.md)
 - [HTTPValidationError](docs/HTTPValidationError.md)
 - [TargetLanguagesResponse](docs/TargetLanguagesResponse.md)
 - [TokenVerificationResponse](docs/TokenVerificationResponse.md)
 - [TransformationInfo](docs/TransformationInfo.md)
 - [TransformationsResponse](docs/TransformationsResponse.md)
 - [TranslationRequest](docs/TranslationRequest.md)
 - [TranslationResponse](docs/TranslationResponse.md)
 - [UserProfileResponse](docs/UserProfileResponse.md)
 - [ValidationError](docs/ValidationError.md)
 - [ValidationErrorLocInner](docs/ValidationErrorLocInner.md)
 - [WordBalanceResponse](docs/WordBalanceResponse.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="ApiKeyAuth"></a>
### ApiKeyAuth

- **Type**: API key
- **API key parameter name**: Authorization
- **Location**: HTTP header


## Author




